OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Não é possível gravar no diretório \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Geralmente, isso pode ser corrigido dando ao servidor web acesso de gravação ao diretório de configuração.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Mas, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true nele. ",
    "See %s" : "Ver %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "O aplicativo %1$s não está presente ou tem uma versão não compatível com este servidor. Verifique o diretório de aplicativos.",
    "Sample configuration detected" : "Configuração de exemplo detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Foi detectado que a configuração de exemplo foi copiada. Isso pode terminar sua instalação e não é suportado. Por favor leia a documentação antes de realizar mudanças no config.php",
    "The page could not be found on the server." : "A página não pôde ser encontrada no servidor.",
    "%s email verification" : "Verificação de e-mail de %s",
    "Email verification" : "Verificação do endereço de e-mail",
    "Click the following button to confirm your email." : "Clique no botão a seguir para confirmar seu endereço de e-mail.",
    "Click the following link to confirm your email." : "Clique no link a seguir para confirmar seu endereço de e-mail.",
    "Confirm your email" : "Confirmar seu e-mail",
    "Other activities" : "Outras atividades",
    "%1$s and %2$s" : "%1$s e %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
    "Education bundle" : "Pacote Educação",
    "Enterprise bundle" : "Pacote Empresarial",
    "Groupware bundle" : "Pacote Groupware",
    "Hub bundle" : "Pacote Hub",
    "Public sector bundle" : "Pacote Setor Público",
    "Social sharing bundle" : "Pacote Compartilhamento Social",
    "PHP %s or higher is required." : "PHP %s ou superior é necessário.",
    "PHP with a version lower than %s is required." : "É necessária uma versão PHP mais antiga que a %s.",
    "%sbit or higher PHP required." : "%sbit ou PHP maior é requerido.",
    "The following architectures are supported: %s" : "As seguintes plataformas são suportadas: %s",
    "The following databases are supported: %s" : "Os seguintes bancos de dados são suportados: %s",
    "The command line tool %s could not be found" : "A ferramenta de linha de comando %s não pôde ser encontrada",
    "The library %s is not available." : "A biblioteca %s não está disponível.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Uma biblioteca %1$s com uma versão maior que %2$s é requerida - versão disponível %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Uma biblioteca %1$s com uma versão abaixo de%2$s é requerida - versão disponível %3$s.",
    "The following platforms are supported: %s" : "As seguintes plataformas são suportadas: %s",
    "Server version %s or higher is required." : "É requerido um servidor da versão %s ou superior.",
    "Server version %s or lower is required." : "É requerido um servidor da versão %s ou abaixo.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "A conta logada deve ser um administrador, um subadministrador ou ter direito especial para acessar esta configuração",
    "Your current IP address doesn't allow you to perform admin actions" : "Seu endereço IP atual não permite que você execute ações administrativas",
    "Logged in account must be an admin or sub admin" : "A conta logada deve ser um administrador ou subadministrador",
    "Logged in account must be an admin" : "A conta logada deve ser um administrador",
    "Wiping of device %s has started" : "Limpeza do dispositivo %s iniciou",
    "Wiping of device »%s« has started" : "A limpeza do dispositivo »%s« terminou",
    "»%s« started remote wipe" : "»%s« iniciou a limpeza remota",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "O dispositivo ou aplicativo »%s« iniciou o processo de limpeza remota. Você receberá outro e-mail assim que terminar",
    "Wiping of device %s has finished" : "Limpeza do dispositivo %s terminou",
    "Wiping of device »%s« has finished" : "Limpeza do dispositivo »%s« terminou",
    "»%s« finished remote wipe" : "»%s« terminou a limpeza remota",
    "Device or application »%s« has finished the remote wipe process." : "O dispositivo ou aplicativo »%s« terminou o processo de limpeza remota.",
    "Remote wipe started" : "Limpeza remota iniciada",
    "A remote wipe was started on device %s" : "Uma limpeza remota iniciou no dispositivo %s",
    "Remote wipe finished" : "Limpeza remota terminada",
    "The remote wipe on %s has finished" : "A limpeza remota em %s terminou",
    "Authentication" : "Autenticação",
    "Unknown filetype" : "Tipo de arquivo desconhecido",
    "Invalid image" : "Imagem inválida",
    "Avatar image is not square" : "A imagem do avatar não é quadrada",
    "Files" : "Arquivos",
    "View profile" : "Visualizar perfil",
    "same time" : "mesmo horário",
    "_%nh_::_%nh_" : ["%nh","%nh","%nh"],
    "_%nm_::_%nm_" : ["%nm","%nm","%nm"],
    "%s ahead" : "%s à frente",
    "%s behind" : "%s atrás",
    "Local time: %s" : "Horário local: %s",
    "today" : "hoje",
    "tomorrow" : "amanhã",
    "yesterday" : "ontem",
    "_in %n day_::_in %n days_" : ["em %n dia","em %n dias","em %n dias"],
    "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás","%n dias atrás"],
    "next month" : "Mês que vem",
    "last month" : "último mês",
    "_in %n month_::_in %n months_" : ["em %n mês","em %n meses","em %n meses"],
    "_%n month ago_::_%n months ago_" : ["%n mês atrás","%n meses atrás","%n meses atrás"],
    "next year" : "próximo ano",
    "last year" : "último ano",
    "_in %n year_::_in %n years_" : ["em %n ano","em %n anos","em %n anos"],
    "_%n year ago_::_%n years ago_" : ["%n ano atrás","%n anos atrás","%n anos atrás"],
    "_in %n hour_::_in %n hours_" : ["em %n hora","em %n horas","em %n horas"],
    "_%n hour ago_::_%n hours ago_" : ["%n hora atrás","%n horas atrás","%n horas atrás"],
    "_in %n minute_::_in %n minutes_" : ["em %n minuto","em %n minutos","em %n minutos"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minuto atrás","%n minutos atrás","%n minutos atrás"],
    "in a few seconds" : "Em alguns segundos",
    "seconds ago" : "segundos atrás",
    "Empty file" : "Arquivo vazio",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "O módulo com a ID: %s não existe. Por favor, habilite-o nas configurações de seu aplicativo ou contacte o administrador.",
    "No file conversion providers available" : "Não há provedores de conversão de arquivos disponíveis",
    "File is too large to convert" : "O arquivo é muito grande para converter",
    "Destination does not match conversion extension" : "O destino não corresponde à extensão de conversão",
    "Could not convert file" : "Não foi possível converter o arquivo",
    "Destination does not exist" : "Destino não existe",
    "Destination is not creatable" : "Destino não pode ser criado",
    "Dot files are not allowed" : "Arquivos Dot não são permitidos",
    "%1$s (renamed)" : "%1$s (renomeado)",
    "renamed file" : "arquivo renomeado",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" é um nome de arquivo ou pasta proibido.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" é um prefixo proibido para nomes de arquivos ou pastas.",
    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" não é permitido dentro de um nome de arquivo ou pasta.",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\" é um tipo de arquivo proibido.",
    "Filenames must not end with \"%1$s\"." : "Os nomes dos arquivos não devem terminar com \"%1$s\".",
    "Invalid parent path" : "Caminho pai inválido",
    "File already exists" : "O arquivo já existe",
    "Invalid path" : "Caminho inválido",
    "Failed to create file from template" : "Falha ao criar arquivo a partir do modelo",
    "Templates" : "Modelos ",
    "Storage %s cannot be moved" : "O armazenamento %s não pode ser movido",
    "Moving a share (%s) into a shared folder is not allowed" : "Não é permitido mover um compartilhamento (%s) para uma pasta compartilhada",
    "Moving a storage (%s) into a shared folder is not allowed" : "Não é permitido mover um armazenamento (%s) para uma pasta compartilhada",
    "Moving a share (%s) into another share (%s) is not allowed" : "Não é permitido mover um compartilhamento (%s) para outro compartilhamento (%s)",
    "Moving a share (%s) into another storage (%s) is not allowed" : "Não é permitido mover um compartilhamento (%s) para outro armazenamento (%s)",
    "Moving a storage (%s) into a share (%s) is not allowed" : "Não é permitido mover um armazenamento (%s) para um compartilhamento (%s)",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "Não é permitido mover um armazenamento (%s) para outro armazenamento (%s)",
    "Path contains invalid segments" : "O caminho contém segmentos inválidos",
    "Filename is a reserved word" : "Nome do arquivo é uma palavra reservada",
    "Filename contains at least one invalid character" : "O nome do arquivo contém pelo menos um caractere inválido  ",
    "Filename is too long" : "O nome do arquivo é muito longo",
    "Empty filename is not allowed" : "Nome vazio para arquivo não é permitido.",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "O aplicativo \"%s\" não pode ser instalado pois o arquivo appinfo não pôde ser lido.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "O aplicativo \"%s\" não pode ser instalado pois não é compatível com a versão do servidor.",
    "__language_name__" : "Português Brasileiro",
    "This is an automatically sent email, please do not reply." : "Este e-mail é enviado automaticamente. Por favor, não responda.",
    "Help & privacy" : "Ajuda & privacidade",
    "Appearance and accessibility" : "Aparência e acessibilidade",
    "Apps" : "Aplicativos",
    "Personal settings" : "Configurações pessoais",
    "Administration settings" : "Configurações de administração",
    "Settings" : "Configurações",
    "Log out" : "Sair",
    "Accounts" : "Contas",
    "Bluesky" : "Bluesky",
    "View %s on Bluesky" : "Ver %s no Bluesky",
    "Email" : "E-mail",
    "Mail %s" : "Enviar e-mail para %s",
    "Fediverse" : "Fediverso",
    "View %s on the fediverse" : "Ver %s no fediverso",
    "Phone" : "Fone",
    "Call %s" : "Ligar para %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Ver %s no Twitter",
    "Website" : "Site",
    "Visit %s" : "Visitar %s",
    "Address" : "Endereço",
    "Profile picture" : "Foto do perfil",
    "About" : "Sobre",
    "Display name" : "Nome de exibição",
    "Headline" : "Título",
    "Organization" : "Organização",
    "Role" : "Função",
    "Pronouns" : "Pronomes",
    "Unknown account" : "Conta desconhecida",
    "Additional settings" : "Configurações adicionais",
    "Enter the database Login and name for %s" : "Insira o login e o nome do banco de dados para %s",
    "Enter the database Login for %s" : "Insira o login do banco de dados para %s",
    "Enter the database name for %s" : "Insira o nome do banco de dados para %s",
    "You cannot use dots in the database name %s" : "Você não pode usar pontos no nome do banco de dados %s",
    "MySQL Login and/or password not valid" : "Login e/ou senha do MySQL inválidos",
    "You need to enter details of an existing account." : "Você necessita entrar detalhes de uma conta existente.",
    "Oracle connection could not be established" : "Conexão Oracle não pôde ser estabelecida",
    "Oracle Login and/or password not valid" : "Login e/ou senha do Oracle inválidos",
    "PostgreSQL Login and/or password not valid" : "Login e/ou senha do PostgreSQL inválidos",
    "For the best results, please consider using a GNU/Linux server instead." : "Para obter melhores resultados, por favor considere o uso de um servidor GNU/Linux em seu lugar.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Aparentemente a instância %s está rodando em um ambiente PHP de 32 bits e o open_basedir foi configurado no php.ini. Isto pode gerar problemas com arquivos maiores que 4GB e é altamente não recomendável.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a configuração de open_basedir de seu php.ini ou mude o PHP para 64bit.",
    "Set an admin Login." : "Defina um login de administrador.",
    "Set an admin password." : "Defina uma senha para o administrador.",
    "Cannot create or write into the data directory %s" : "Não foi possível criar ou escrever no diretório de dados %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A plataforma de compartilhamento %s deve implementar a interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Plataforma de serviço de compartilhamento %s não encontrada",
    "Sharing backend for %s not found" : "Plataforma  de compartilhamento para %s não foi encontrada",
    "%1$s shared %2$s with you" : "%1$s compartilhou %2$s com você",
    "Open %s" : "Abrir %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s compartilhou %2$s com você e deseja adicionar:",
    "%1$s shared %2$s with you and wants to add" : "%1$s compartilhou %2$s com você e deseja adicionar",
    "%s added a note to a file shared with you" : "%s adicionou uma nota a um arquivo compartilhado com você",
    "Passwords are enforced for link and mail shares" : "As senhas são obrigatórias para compartilhamentos de links e e-mails",
    "Share recipient is not a valid user" : "O destinatário do compartilhamento não é um usuário válido",
    "Share recipient is not a valid group" : "O destinatário do compartilhamento não é um grupo válido",
    "Share recipient should be empty" : "O destinatário do compartilhamento deve estar vazio",
    "Share recipient should not be empty" : "O destinatário do compartilhamento não deve estar vazio",
    "Share recipient is not a valid circle" : "O destinatário do compartilhamento não é um círculo válido",
    "Unknown share type" : "Tipo de compartilhamento desconhecido",
    "Share initiator must be set" : "O iniciador de compartilhamento deve estar definido",
    "Cannot share with yourself" : "Não é possível compartilhar consigo mesmo",
    "Shared path must be set" : "O caminho do compartilhamento deve estar definido",
    "Shared path must be either a file or a folder" : "O caminho do compartilhamento deve ser ou um arquivo ou uma pasta",
    "You cannot share your root folder" : "Você não pode compartilhar sua pasta raiz",
    "You are not allowed to share %s" : "Você não tem permissão para compartilhar %s",
    "Valid permissions are required for sharing" : "Permissões válidas são necessárias para compartilhamento",
    "File shares cannot have create or delete permissions" : "Os compartilhamentos de arquivos não podem ter permissões de criação ou exclusão",
    "Cannot increase permissions of %s" : "Não foi possível aumentar as permissões de %s",
    "Shares need at least read permissions" : "Compartilhamentos precisam pelo menos permissões de leitura",
    "Files cannot be shared with delete permissions" : "Arquivos não podem ser compartilhados com permissões de exclusão",
    "Files cannot be shared with create permissions" : "Arquivos não podem ser compartilhados com permissões de criação",
    "Expiration date is in the past" : "Data de expiração está no passado",
    "Expiration date is enforced" : "A data de expiração é aplicada",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Não é possível definir a data de expiração para mais de %n dia no futuro","Não é possível definir a data de expiração para mais de %n dias no futuro","Não é possível definir a data de expiração para mais de %n dias no futuro"],
    "Sharing is only allowed with group members" : "O compartilhamento só é permitido com membros do grupo ",
    "Sharing %s failed, because this item is already shared with the account %s" : "O compartilhamento do %s falhou, porque esse item já está compartilhado com a conta %s",
    "Group sharing is now allowed" : "O compartilhamento em grupo é permitido agora",
    "Sharing is only allowed within your own groups" : "O compartilhamento só é permitido dentro de seus próprios grupos",
    "Path is already shared with this group" : "O caminho já está compartilhado com este grupo",
    "Link sharing is not allowed" : "O compartilhamento de links não é permitido",
    "Public upload is not allowed" : "O upload público não é permitido",
    "You cannot share a folder that contains other shares" : "Você não pode compartilhar uma pasta que contém outros compartilhamentos",
    "Sharing is disabled" : "O compartilhamento está desativado",
    "Sharing is disabled for you" : "O compartilhamento está desativado para você",
    "Cannot share with the share owner" : "Não é possível compartilhar com o proprietário do compartilhamento",
    "Share does not have a full ID" : "O compartilhamento não tem um ID completo",
    "Cannot change share type" : "Não é possível alterar o tipo de compartilhamento",
    "Can only update recipient on user shares" : "Só é possível atualizar o destinatário em compartilhamentos de usuários",
    "Cannot enable sending the password by Talk with an empty password" : "Não é possível ativar o envio da senha pelo Talk com uma senha vazia",
    "Cannot enable sending the password by Talk without setting a new password" : "Não é possível ativar o envio da senha pelo Talk sem definir uma nova senha",
    "Cannot disable sending the password by Talk without setting a new password" : "Não é possível desativar o envio da senha pelo Talk sem definir uma nova senha",
    "Share provider does not support accepting" : "O provedor de compartilhamento não oferece suporte à aceitação",
    "Cannot change target of link share" : "Não é possível alterar o destino do compartilhamento do link",
    "Invalid share recipient" : "Destinatário de compartilhamento inválido",
    "Group \"%s\" does not exist" : "Grupo \"%s\" não existe",
    "The requested share does not exist anymore" : "O compartilhamento solicitado não existe mais",
    "The requested share comes from a disabled user" : "O compartilhamento solicitado vem de um usuário desabilitado",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "O usuário não foi criado porque o limite de usuários foi atingido. Confira suas notificações para saber mais.",
    "Could not find category \"%s\"" : "Impossível localizar a categoria \"%s\"",
    "Input text" : "Texto de entrada",
    "The input text" : "O texto de entrada",
    "Sunday" : "Domingo",
    "Monday" : "Segunda-feira",
    "Tuesday" : "Terça-feira",
    "Wednesday" : "Quarta-feira",
    "Thursday" : "Quinta-feira",
    "Friday" : "Sexta-feira",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Seg.",
    "Tue." : "Ter.",
    "Wed." : "Qua.",
    "Thu." : "Qui.",
    "Fri." : "Sex.",
    "Sat." : "Sab.",
    "Su" : "Su",
    "Mo" : "Se",
    "Tu" : "Te",
    "We" : "Qu",
    "Th" : "Qu",
    "Fr" : "Se",
    "Sa" : "Sa",
    "January" : "Janeiro",
    "February" : "Fevereiro",
    "March" : "Março",
    "April" : "Abril",
    "May" : "Maio",
    "June" : "Junho",
    "July" : "Julho",
    "August" : "Agosto",
    "September" : "Setembro",
    "October" : "Outubro",
    "November" : "Novembro",
    "December" : "Dezembro",
    "Jan." : "Jan.",
    "Feb." : "Fev.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Out.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "A valid password must be provided" : "Uma senha válida deve ser fornecida",
    "The Login is already being used" : "O Login já está sendo usado",
    "Could not create account" : "Não foi possível criar a conta",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Somente os seguintes caracteres são permitidos em um Login: \"a-z\", \"A-Z\", \"0-9\", espaços e \"_.@-'\"",
    "A valid Login must be provided" : "Um Login válido deve ser fornecido",
    "Login contains whitespace at the beginning or at the end" : "O login contém espaços em branco no início ou no final",
    "Login must not consist of dots only" : "O login não deve consistir apenas de pontos",
    "Username is too long" : "O nome de usuário é muito longo",
    "Login is invalid because files already exist for this user" : "O login é inválido porque já existem arquivos para este usuário",
    "Account disabled" : "Conta desativada",
    "Login canceled by app" : "Login cancelado pelo aplicativo",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "O aplicativo \"%1$s\" não pode ser instalado devido à estas dependências: %2$s",
    "a safe home for all your data" : "Um lar seguro para todos os seus dados",
    "Application is not enabled" : "O aplicativo não está habilitado",
    "Authentication error" : "Erro de autenticação",
    "Token expired. Please reload page." : "O token expirou. Por favor recarregue a página.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nenhum driver  de banco de dados (sqlite, mysql ou postgresql) instalado.",
    "Cannot write into \"config\" directory." : "Não é possível gravar no diretório \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Geralmente, isso pode ser corrigido dando ao servidor web acesso de gravação ao diretório de configuração. Consulte %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true. Veja %s",
    "Cannot create \"data\" directory." : "Não é possível criar o diretório \"data\".",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Geralmente, isso pode ser corrigido dando ao servidor web acesso de gravação ao diretório raiz. Consulte %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Geralmente, as permissões podem ser corrigidas dando ao servidor web acesso de gravação ao diretório raiz. Consulte %s.",
    "Your data directory is not writable." : "Seu diretório de dados não é gravável.",
    "Setting locale to %s failed." : "Falha ao definir a configuração regional para %s.",
    "Please install one of these locales on your system and restart your web server." : "Por favor, instale uma dessas configurações regionais em seu sistema e reinicie seu servidor web.",
    "PHP module %s not installed." : "Módulo PHP %s não instalado.",
    "Please ask your server administrator to install the module." : "Por favor, peça ao seu administrador do servidor para instalar o módulo.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Configuração PHP \"%s\" não está configurado para \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajustar a configuração no php.ini fará com que o Nextcloud execute novamente",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP aparentemente está configurado para retirar blocos doc inline. Isso fará com que vários aplicativos do núcleo fiquem inacessíveis.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isso provavelmente é causado por um cache/acelerador, como Zend OPcache ou eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Módulos do PHP foram instalados, mas eles ainda estão listados como faltantes?",
    "Please ask your server administrator to restart the web server." : "Por favor peça ao administrador do servidor para reiniciar o servidor web.",
    "The required %s config variable is not configured in the config.php file." : "A variável de configuração %s obrigatória não está configurada no arquivo config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Peça ao administrador do servidor para verificar a configuração do Nextcloud.",
    "Your data directory is readable by other people." : "Seu diretório de dados pode ser lido por outras pessoas.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Altere as permissões para 0770 para que o diretório não possa ser listado por outras pessoas.",
    "Your data directory must be an absolute path." : "Seu diretório de dados deve ser um caminho absoluto.",
    "Check the value of \"datadirectory\" in your configuration." : "Verifique o valor de \"datadirectory\" em sua configuração.",
    "Your data directory is invalid." : "Seu diretório de dados é inválido.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Certifique-se de que há um arquivo chamado \"%1$s\" na raiz do diretório de dados. Ele deve ter o conteúdo: \"%2$s\"",
    "Action \"%s\" not supported or implemented." : "Ação \"%s\" não suportada ou implementada.",
    "Authentication failed, wrong token or provider ID given" : "Falha na autenticação, token ou ID do provedor errados",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parâmetros ausentes para concluir a solicitação: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "A ID \"%1$s\" já é usada pelo provedor de nuvem federada \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Provedor da Federação de Nuvem com ID: \"%s\" não existe.",
    "Could not obtain lock type %d on \"%s\"." : "Não foi possível obter tipo de trancamento %d em \"%s\".",
    "Storage unauthorized. %s" : "Armazenamento não autorizado. %s",
    "Storage incomplete configuration. %s" : "Configuração incompleta do armazenamento. %s",
    "Storage connection error. %s" : "Erro na conexão de armazenamento. %s",
    "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
    "Storage connection timeout. %s" : "Atingido o tempo limite de conexão ao armazenamento. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Para permitir que esta verificação seja executada, você deve certificar-se de que seu servidor web pode se conectar a si mesmo. Portanto, ele deve ser capaz de resolver e conectar a pelo menos um de seus `trusted_domains` ou `overwrite.cli.url`. Esta falha pode ser o resultado de uma incompatibilidade de DNS no servidor ou de uma regra de firewall de saída.",
    "Analyze images" : "Analisar imagens",
    "Ask a question about the given images." : "Faça uma pergunta sobre as imagens fornecidas.",
    "Images" : "Imagens",
    "Images to ask a question about" : "Imagens sobre as quais fazer uma pergunta",
    "Question" : "Pergunta",
    "What to ask about the images." : "O que perguntar sobre as imagens.",
    "Generated response" : "Resposta gerada",
    "The answer to the question" : "A resposta à pergunta",
    "Audio chat" : "Conversa por áudio",
    "Voice chat with the assistant" : "Conversa por voz com o assistente",
    "System prompt" : "Prompt do sistema",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Defina regras e suposições que o assistente deve seguir durante a conversa.",
    "Chat voice message" : "Mensagem de voz no chat",
    "Describe a task that you want the assistant to do or ask a question." : "Descreva uma tarefa que você deseja que o assistente faça ou faça uma pergunta.",
    "Chat history" : "Histórico de bate-papo",
    "The history of chat messages before the current message, starting with a message by the user." : "O histórico de mensagens de bate-papo antes da mensagem atual, começando com uma mensagem do usuário.",
    "Input transcript" : "Transcrição da entrada",
    "Transcription of the audio input" : "Transcrição da entrada de áudio",
    "Response voice message" : "Mensagem de voz de resposta",
    "The generated voice response as part of the conversation" : "A resposta de voz gerada como parte da conversa",
    "Output transcript" : "Transcrição da saída",
    "Transcription of the audio output" : "Transcrição da saída de áudio",
    "Transcribe audio" : "Transcrever áudio",
    "Transcribe the things said in an audio" : "Transcrever o que foi dito em um áudio",
    "Audio input" : "Entrada de áudio",
    "The audio to transcribe" : "O áudio a ser transcrito",
    "Transcription" : "Transcrição",
    "The transcribed text" : "O texto transcrito",
    "Chat by voice with an agent" : "Bate-papo por voz com um agente",
    "Describe a task that you want the agent to do or ask a question." : "Descreva uma tarefa que você deseja que o agente faça ou faça uma pergunta.",
    "Confirmation" : "Confirmação",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Se deve confirmar as ações solicitadas anteriormente: 0 para negação e 1 para confirmação.",
    "Conversation token" : "Token de conversação",
    "A token representing the conversation." : "Um token que representa a conversa.",
    "The new conversation token" : "O novo token de conversa",
    "Send this along with the next interaction." : "Envie isso junto com a próxima interação.",
    "Requested actions by the agent" : "Ações solicitadas pelo agente",
    "Actions that the agent would like to carry out in JSON format." : "Ações que o agente gostaria de realizar no formato JSON.",
    "Chat with an agent" : "Conversar com um agente",
    "Chat message" : "Mensagem de bate-papo",
    "A chat message to send to the agent." : "Uma mensagem de bate-papo a ser enviada ao agente",
    "The response from the chat model." : "A resposta do modelo de bate-papo.",
    "Context write" : "Escrita contextual",
    "Writes text in a given style based on the provided source material." : "Escreve texto em um determinado estilo com base no material de origem fornecido.",
    "Writing style" : "Estilo de escrita",
    "Demonstrate a writing style that you would like to immitate" : "Demonstre um estilo de escrita que você gostaria de imitar",
    "Source material" : "Material de origem",
    "The content that would like to be rewritten in the new writing style" : "O conteúdo que gostaria de ser reescrito no novo estilo de escrita",
    "Generated text" : "Texto gerado",
    "The generated text with content from the source material in the given style" : "O texto gerado com conteúdo do material de origem no estilo determinado",
    "Emoji generator" : "Gerador de emojis",
    "Takes text and generates a representative emoji for it." : "Pega texto e gera um emoji representativo para ele.",
    "The text to generate an emoji for" : "O texto para o qual gerar um emoji",
    "Generated emoji" : "Emoji gerado",
    "The generated emoji based on the input text" : "O emoji gerado com base no texto de entrada",
    "Optical character recognition" : "Reconhecimento ótico de caracteres",
    "Generate image" : "Gerar imagem",
    "Generate an image from a text prompt" : "Gere uma imagem a partir de um prompt de texto",
    "Prompt" : "Prompt",
    "Describe the image you want to generate" : "Descreva a imagem que você deseja gerar",
    "Number of images" : "Número de imagens",
    "How many images to generate" : "Quantas imagens devem ser geradas",
    "Output images" : "Imagens de saída",
    "The generated images" : "As imagens geradas",
    "Generate speech" : "Gerar fala",
    "Generate speech from a transcript" : "Gerar fala a partir de uma transcrição",
    "Write transcript that you want the assistant to generate speech from" : "Escreva a transcrição a partir da qual você deseja que o assistente gere a fala",
    "Output speech" : "Fala de saída",
    "The generated speech" : "A fala gerada",
    "Free text to text prompt" : "Prompt de texto livre para texto",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Usa um modelo de linguagem para gerar uma resposta a partir de um prompt.",
    "Describe a task that you want the assistant to do or ask a question" : "Descreva uma tarefa que você deseja que o assistente execute ou faça uma pergunta",
    "Generated reply" : "Resposta gerada",
    "The generated text from the assistant" : "O texto gerado do assistente",
    "Change Tone" : "Mudar o tom",
    "Change the tone of a piece of text." : "Alterar o tom de um texto.",
    "Write a text that you want the assistant to rewrite in another tone." : "Escreva um texto que você deseja que o assistente reescreva em outro tom.",
    "Desired tone" : "Tom desejado",
    "In which tone should your text be rewritten?" : "Em qual tom seu texto deve ser reescrito?",
    "The rewritten text in the desired tone, written by the assistant:" : "O texto reescrito no tom desejado, escrito pelo assistente:",
    "Chat" : "Bate-papo",
    "Chat with the assistant" : "Converse com o assistente",
    "The history of chat messages before the current message, starting with a message by the user" : "O histórico de mensagens de bate-papo antes da mensagem atual, começando com uma mensagem do usuário",
    "Response message" : "Mensagem de resposta",
    "The generated response as part of the conversation" : "A resposta gerada como parte da conversa",
    "Chat with tools" : "Conversar com ferramentas",
    "Chat with the language model with tool calling support." : "Converse com o modelo de linguagem com suporte a tool calling (\"chamadas a ferramentas\").",
    "Tool message" : "Mensagem da ferramenta",
    "The result of tool calls in the last interaction" : "O resultado das chamadas a ferramentas na última interação",
    "Available tools" : "Ferramentas disponíveis",
    "The available tools in JSON format" : "As ferramentas disponíveis em formato JSON",
    "The response from the chat model" : "A resposta do modelo de bate-papo",
    "Tool calls" : "Chamadas a ferramentas",
    "Tools call instructions from the model in JSON format" : "Instruções para chamadas a ferramentas do modelo no formato JSON",
    "Formalize text" : "Formalizar texto",
    "Takes a text and makes it sound more formal" : "Pega um texto e o faz parecer mais formal",
    "Write a text that you want the assistant to formalize" : "Escreva um texto que você deseja que o assistente formalize",
    "Formalized text" : "Texto formalizado",
    "The formalized text" : "O texto formalizado",
    "Generate a headline" : "Gere um título",
    "Generates a possible headline for a text." : "Gera um possível título para um texto.",
    "Original text" : "Texto original",
    "The original text to generate a headline for" : "O texto original para gerar um título",
    "The generated headline" : "O título gerado",
    "Proofread" : "Revisar",
    "Proofreads a text and lists corrections" : "Revisa um texto e lista as correções",
    "Text" : "Texto",
    "The text to proofread" : "O texto a ser revisado",
    "Corrections" : "Correções",
    "The corrections that should be made in your text" : "As correções que devem ser feitas em seu texto",
    "Reformulate text" : "Reformular texto",
    "Takes a text and reformulates it" : "Pega um texto e o reformula",
    "Write a text that you want the assistant to reformulate" : "Escreva um texto que você deseja que o assistente reformule",
    "Reformulated text" : "Texto reformulado",
    "The reformulated text, written by the assistant" : "O texto reformulado, escrito pelo assistente",
    "Simplify text" : "Simplificar texto",
    "Takes a text and simplifies it" : "Pega um texto e o simplifica",
    "Write a text that you want the assistant to simplify" : "Escreva um texto que você deseja que o assistente simplifique",
    "Simplified text" : "Texto simplificado",
    "The simplified text" : "O texto simplificado",
    "Summarize" : "Resumir",
    "Summarizes a text" : "Resume um texto",
    "The original text to summarize" : "O texto original para resumir",
    "Summary" : "Resumo",
    "The generated summary" : "O resumo gerado",
    "Extract topics" : "Extrair temas",
    "Extracts topics from a text and outputs them separated by commas" : "Extrai temas de um texto e os exibe separados por vírgulas",
    "The original text to extract topics from" : "O texto original do qual extrair temas",
    "Topics" : "Temas",
    "The list of extracted topics" : "A lista de temas extraídos",
    "Translate" : "Traduzir",
    "Translate text from one language to another" : "Traduzir um texto de um idioma para outro",
    "Origin text" : "Texto original",
    "The text to translate" : "O texto a ser traduzido",
    "Origin language" : "Idioma original",
    "The language of the origin text" : "O idioma do texto original",
    "Target language" : "Idioma de destino",
    "The desired language to translate the origin text in" : "O idioma definido para traduzir o texto original",
    "Result" : "Resultado",
    "The translated text" : "O texto traduzido",
    "Free prompt" : "Prompt livre",
    "Runs an arbitrary prompt through the language model." : "Executa um prompt arbitrário por meio do modelo de linguagem.",
    "Generate headline" : "Gerar título",
    "Summarizes text by reducing its length without losing key information." : "Resume o texto reduzindo seu comprimento sem perder informações importantes.",
    "Extracts topics from a text and outputs them separated by commas." : "Extrai temas de um texto e os exibe separados por vírgulas.",
    "Organisation" : "Organização",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "O Mac OS X não é compatível e %s não funcionará corretamente nessa plataforma. Use-o por sua própria conta e risco!",
    "Login is too long" : "Login é muito longo",
    "Cannot write into \"apps\" directory." : "Não é possível gravar no diretório \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Geralmente, isso pode ser corrigido dando ao servidor web acesso de gravação ao diretório de aplicativos ou desabilitando a Loja de Aplicativos no arquivo de configuração.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está configurado para <code>%s</code> em vez do valor esperado <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para corrigir esse problema, defina <code>mbstring.func_overload</code> como <code>0</code> em seu php.ini."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
